#ifndef PROGRESSWINDOW_H
#define PROGRESSWINDOW_H

#include <gui/window.h>
#include <gui/view.h>
#include <gui/layoutview.h>
#include <gui/button.h>
#include <gui/image.h>
#include <gui/listview.h>
#include <gui/statusbar.h>
#include <gui/toolbar.h>
#include <util/resources.h>
#include <util/application.h>
#include <util/message.h>

#include "UpdateMsg.h"
#include "mainwindow.h"

class AppSettings;

enum {
	M_RESUME = 1,
	M_PAUSE = 2,
	M_CANCEL = 3
};

/* Enum for the indecies into the list view. */
enum {
	STATUS_INDEX = 0,
	SERVER_INDEX,
	FILE_INDEX,	
	TRANSFERRED_INDEX,
	FILE_SIZE_INDEX,
	ID_INDEX
};

/** \brief Displays a window containing the progress of downloads.
 * This also allows the user to pause/force the start of items in queue.
 *
 * \todo When this window is closed it closes the whole program. It should just hide
 * until the Terminate method is called.
 */
class ProgressWindow : public os::Window
{
public:
	ProgressWindow(MainWindow *mainWindow, AppSettings* pcSettings);
	~ProgressWindow();
	void HandleMessage( os::Message* );
	bool OkToQuit(void);

	void SendPauseMessage( os::Message* pcMsg );
	void SendResumeMessage( os::Message* pcMsg );
	void SendCancelMessage( os::Message* pcMsg );
	
	void OpenContextMenu( const Point& cPos, int nID );
	
private:
	void UpdateTransfers(Message *psUpdate);

	os::VLayoutNode* m_pcRoot;
	os::StatusBar *m_pcStatusBar;
	os::ListView* m_pcListView;

	MainWindow *m_pcMainWindow;
	AppSettings* m_pcSettings;
};

#endif



